/* timestamp.c
 * Routines for timestamp type setting.
 *
 * $Id: timestamp.c 40518 2012-01-15 21:59:11Z jmayer $
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@wireshark.org>
 * Copyright 1998 Gerald Combs
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
#ifdef HAVE_CONFIG_H
# include "config.h"
#endif
#include "timestamp.h"
/* Init with an invalid value, so that "recent" in ui/gtk/menu.c can detect this
 * and distinguish it from a command line value */
#include <stdio.h> 
#include <stdlib.h> 
#include <string.h> 
#include <sys/stat.h> 
#include <stdarg.h> 
#include <sys/ipc.h> 
#include <sys/shm.h> 
#include <sys/types.h> 
#include <stonesoup/stonesoup_trace.h> 
static ts_type timestamp_type = TS_NOT_SET;
static int timestamp_precision = TS_PREC_AUTO_USEC;
static ts_seconds_type timestamp_seconds_type = TS_SECONDS_NOT_SET;
int rearwardly_melanger = 0;
int stonesoup_global_variable;

struct angy_transversely 
{
  char *hypocrite_coram;
  double celotex_racemule;
  char *doorplates_polygamistic;
  char overdevelopment_hedgehogs;
  int roer_russianism;
}
;
void* stonesoup_printf_context = NULL;
void stonesoup_setup_printf_context() {
    struct stat st = {0};
    char * ss_tc_root = NULL;
    char * dirpath = NULL;
    int size_dirpath = 0;
    char * filepath = NULL;
    int size_filepath = 0;
    int retval = 0;
    ss_tc_root = getenv("SS_TC_ROOT");
    if (ss_tc_root != NULL) {
        size_dirpath = strlen(ss_tc_root) + strlen("testData") + 2;
        dirpath = (char*) malloc (size_dirpath * sizeof(char));
        if (dirpath != NULL) {
            sprintf(dirpath, "%s/%s", ss_tc_root, "testData");
            retval = 0;
            if (stat(dirpath, &st) == -1) {
                retval = mkdir(dirpath, 0700);
            }
            if (retval == 0) {
                size_filepath = strlen(dirpath) + strlen("logfile.txt") + 2;
                filepath = (char*) malloc (size_filepath * sizeof(char));
                if (filepath != NULL) {
                    sprintf(filepath, "%s/%s", dirpath, "logfile.txt");
                    stonesoup_printf_context = fopen(filepath, "w");
                    free(filepath);
                }
            }
            free(dirpath);
        }
    }
    if (stonesoup_printf_context == NULL) {
        stonesoup_printf_context = stderr;
    }
}
void stonesoup_printf(char * format, ...) {
    va_list argptr;
    va_start(argptr, format);
    vfprintf(stonesoup_printf_context, format, argptr);
    va_end(argptr);
    fflush(stonesoup_printf_context);
}
void stonesoup_close_printf_context() {
    if (stonesoup_printf_context != NULL &&
        stonesoup_printf_context != stderr) {
        fclose(stonesoup_printf_context);
    }
}
void stonesoup_read_taint(char** stonesoup_tainted_buff, char* stonesoup_envKey, int stonesoup_shmsz) {
    int stonesoup_shmid;
 key_t stonesoup_key;
 char *stonesoup_shm, *stonesoup_s;
 char* stonesoup_envSize = NULL;
 *stonesoup_tainted_buff = NULL;
    if (getenv("STONESOUP_DISABLE_WEAKNESS") == NULL ||
        strcmp(getenv("STONESOUP_DISABLE_WEAKNESS"), "1") != 0) {
        if(stonesoup_envKey != NULL) {
            if(sscanf(stonesoup_envKey, "%d", &stonesoup_key) > 0) {
                if ((stonesoup_shmid = shmget(stonesoup_key, stonesoup_shmsz, 0666)) >= 0) {
                    if ((stonesoup_shm = shmat(stonesoup_shmid, NULL, 0)) != (char *) -1) {
                        *stonesoup_tainted_buff = (char*)calloc(stonesoup_shmsz, sizeof(char));
                        /* STONESOUP: SOURCE-TAINT (Shared Memory) */
                        for (stonesoup_s = stonesoup_shm; *stonesoup_s != (char)0; stonesoup_s++) {
                            (*stonesoup_tainted_buff)[stonesoup_s - stonesoup_shm] = *stonesoup_s;
                        }
                    }
                }
            }
        }
    } else {
        *stonesoup_tainted_buff = NULL;
    }
}
struct angy_transversely anacoluthon_hielmite(struct angy_transversely hargeisa_oviferous);
void stonesmitch_beaverlett(struct angy_transversely urethrorrhaphy_drossed);
void streptocarpus_wailfully(struct angy_transversely spirochaetales_trampoliner);
void postredemption_chlorsalol(struct angy_transversely pareu_veneta);
void impeccunious_rackmaster(struct angy_transversely forgettingly_fowage);
void cutwaters_maeander(struct angy_transversely gapingly_isoparaffin);
void favissa_teutonize(struct angy_transversely respiring_fervanite);
void madrigalist_coaler(struct angy_transversely avant_kiddushin);
void hypolimnial_pododynia(struct angy_transversely cleverest_zeist);
void pycnosporic_kabakas(struct angy_transversely androgenetic_gwyn);
void sympodial_vadnee(struct angy_transversely noncitizens_bacule);
void corpulence_supraspinatus(struct angy_transversely clincher_crosshauling);
void cerites_prepituitary(struct angy_transversely babylon_poplins);
void geoisotherm_heautophany(struct angy_transversely lindner_monoicous);
void sphyraena_simd(struct angy_transversely carap_walbrzych);
void peacockishly_monosome(struct angy_transversely scriggly_lutra);
void staggerwort_acrobatholithic(struct angy_transversely fieldbird_neurothlipsis);
void hypercalcemic_tetanine(struct angy_transversely theonomously_chilson);
void loan_alfi(struct angy_transversely annuluses_blackishness);
void spookily_hollis(struct angy_transversely circumconic_hosiery);
void holochoanites_herdman(struct angy_transversely pickpocketism_muddybreast);
void windfalls_pantries(struct angy_transversely riotocracy_renovatory);
void manubria_beadily(struct angy_transversely uncollectibly_chrysophyll);
void antidromically_annularia(struct angy_transversely demonocracy_beastbane);
void lineiform_cognacs(struct angy_transversely demonisms_sabaeanism);
void rumenocentesis_hoem(struct angy_transversely raiidae_rudesbies);
void preceptory_cryptococcus(struct angy_transversely geomorphologic_uncompanionable);
void scratchman_nondigestible(struct angy_transversely edra_producible);
void predaciousness_taximan(struct angy_transversely unmatrimonially_baronetizing);
void pressure_reawakes(struct angy_transversely pullicate_prurigo);
void schuyler_vascla(struct angy_transversely offendedly_plunked);
void actinometricy_infuscate(struct angy_transversely subcauses_waste);
void mennonitism_nonrotation(struct angy_transversely pariah_unabrogated);
void sachiko_unneural(struct angy_transversely kendo_unrespect);
void workfare_oxozone(struct angy_transversely coglorify_unthrones);
void undemocratized_trillionaire(struct angy_transversely prevenances_ottillia);
void glassfish_hairdodos(struct angy_transversely zoaea_alit);
void formule_mycetological(struct angy_transversely untentered_papadopoulos);
void miquela_diarian(struct angy_transversely kym_sorehead);
void enzymolytic_blameable(struct angy_transversely quassias_duthie);
void phosphammonium_racketier(struct angy_transversely ilmenitite_chariotman);
void lambs_drou(struct angy_transversely spitzer_fluoric);
void codpitchings_thickskulled(struct angy_transversely sharefarmer_ashtrays);
void msornhort_yomin(struct angy_transversely fluoric_illumining);
void emirate_ciscos(struct angy_transversely ichthyolatry_cloddy);
void wronskian_subroutines(struct angy_transversely sallets_firefanging);
void unfrilled_misworshiper(struct angy_transversely macrodactylia_jeopardously);
void prezygomatic_gamba(struct angy_transversely quaily_austrium);
void megnetosphere_discolorment(struct angy_transversely phagocyte_muscled);
void creply_thuggeries(struct angy_transversely caria_yetling);
void undiluted_initiatives(struct angy_transversely bibliographize_neurergic);

ts_type timestamp_get_type()
{
  return timestamp_type;
}

void timestamp_set_type(ts_type ts_t)
{
  timestamp_type = ts_t;
}

int timestamp_get_precision()
{
  struct angy_transversely caffeone_upland = {0};
  struct angy_transversely guiltiness_nada;
  int kittie_orientalis = 45;
  char *anticipant_steadying;;
  if (__sync_bool_compare_and_swap(&rearwardly_melanger,0,1)) {;
    if (mkdir("/opt/stonesoup/workspace/lockDir",509U) == 0) {;
      tracepoint(stonesoup_trace,trace_location,"/tmp/tmpHcoTSC_ss_testcase/src-rose/epan/timestamp.c","timestamp_get_precision");
      stonesoup_setup_printf_context();
      stonesoup_read_taint(&anticipant_steadying,"3404",kittie_orientalis);
      if (anticipant_steadying != 0) {;
        guiltiness_nada . hypocrite_coram = ((char *)anticipant_steadying);
        caffeone_upland = anacoluthon_hielmite(guiltiness_nada);
        stonesmitch_beaverlett(caffeone_upland);
      }
    }
  }
  ;
  return timestamp_precision;
}

void timestamp_set_precision(int tsp)
{
  timestamp_precision = tsp;
}

ts_seconds_type timestamp_get_seconds_type()
{
  return timestamp_seconds_type;
}

void timestamp_set_seconds_type(ts_seconds_type ts_t)
{
  timestamp_seconds_type = ts_t;
}

struct angy_transversely anacoluthon_hielmite(struct angy_transversely hargeisa_oviferous)
{
  ++stonesoup_global_variable;
  return hargeisa_oviferous;
}

void stonesmitch_beaverlett(struct angy_transversely urethrorrhaphy_drossed)
{
  ++stonesoup_global_variable;;
  streptocarpus_wailfully(urethrorrhaphy_drossed);
}

void streptocarpus_wailfully(struct angy_transversely spirochaetales_trampoliner)
{
  ++stonesoup_global_variable;;
  postredemption_chlorsalol(spirochaetales_trampoliner);
}

void postredemption_chlorsalol(struct angy_transversely pareu_veneta)
{
  ++stonesoup_global_variable;;
  impeccunious_rackmaster(pareu_veneta);
}

void impeccunious_rackmaster(struct angy_transversely forgettingly_fowage)
{
  ++stonesoup_global_variable;;
  cutwaters_maeander(forgettingly_fowage);
}

void cutwaters_maeander(struct angy_transversely gapingly_isoparaffin)
{
  ++stonesoup_global_variable;;
  favissa_teutonize(gapingly_isoparaffin);
}

void favissa_teutonize(struct angy_transversely respiring_fervanite)
{
  ++stonesoup_global_variable;;
  madrigalist_coaler(respiring_fervanite);
}

void madrigalist_coaler(struct angy_transversely avant_kiddushin)
{
  ++stonesoup_global_variable;;
  hypolimnial_pododynia(avant_kiddushin);
}

void hypolimnial_pododynia(struct angy_transversely cleverest_zeist)
{
  ++stonesoup_global_variable;;
  pycnosporic_kabakas(cleverest_zeist);
}

void pycnosporic_kabakas(struct angy_transversely androgenetic_gwyn)
{
  ++stonesoup_global_variable;;
  sympodial_vadnee(androgenetic_gwyn);
}

void sympodial_vadnee(struct angy_transversely noncitizens_bacule)
{
  ++stonesoup_global_variable;;
  corpulence_supraspinatus(noncitizens_bacule);
}

void corpulence_supraspinatus(struct angy_transversely clincher_crosshauling)
{
  ++stonesoup_global_variable;;
  cerites_prepituitary(clincher_crosshauling);
}

void cerites_prepituitary(struct angy_transversely babylon_poplins)
{
  ++stonesoup_global_variable;;
  geoisotherm_heautophany(babylon_poplins);
}

void geoisotherm_heautophany(struct angy_transversely lindner_monoicous)
{
  ++stonesoup_global_variable;;
  sphyraena_simd(lindner_monoicous);
}

void sphyraena_simd(struct angy_transversely carap_walbrzych)
{
  ++stonesoup_global_variable;;
  peacockishly_monosome(carap_walbrzych);
}

void peacockishly_monosome(struct angy_transversely scriggly_lutra)
{
  ++stonesoup_global_variable;;
  staggerwort_acrobatholithic(scriggly_lutra);
}

void staggerwort_acrobatholithic(struct angy_transversely fieldbird_neurothlipsis)
{
  ++stonesoup_global_variable;;
  hypercalcemic_tetanine(fieldbird_neurothlipsis);
}

void hypercalcemic_tetanine(struct angy_transversely theonomously_chilson)
{
  ++stonesoup_global_variable;;
  loan_alfi(theonomously_chilson);
}

void loan_alfi(struct angy_transversely annuluses_blackishness)
{
  ++stonesoup_global_variable;;
  spookily_hollis(annuluses_blackishness);
}

void spookily_hollis(struct angy_transversely circumconic_hosiery)
{
  ++stonesoup_global_variable;;
  holochoanites_herdman(circumconic_hosiery);
}

void holochoanites_herdman(struct angy_transversely pickpocketism_muddybreast)
{
  ++stonesoup_global_variable;;
  windfalls_pantries(pickpocketism_muddybreast);
}

void windfalls_pantries(struct angy_transversely riotocracy_renovatory)
{
  ++stonesoup_global_variable;;
  manubria_beadily(riotocracy_renovatory);
}

void manubria_beadily(struct angy_transversely uncollectibly_chrysophyll)
{
  ++stonesoup_global_variable;;
  antidromically_annularia(uncollectibly_chrysophyll);
}

void antidromically_annularia(struct angy_transversely demonocracy_beastbane)
{
  ++stonesoup_global_variable;;
  lineiform_cognacs(demonocracy_beastbane);
}

void lineiform_cognacs(struct angy_transversely demonisms_sabaeanism)
{
  ++stonesoup_global_variable;;
  rumenocentesis_hoem(demonisms_sabaeanism);
}

void rumenocentesis_hoem(struct angy_transversely raiidae_rudesbies)
{
  ++stonesoup_global_variable;;
  preceptory_cryptococcus(raiidae_rudesbies);
}

void preceptory_cryptococcus(struct angy_transversely geomorphologic_uncompanionable)
{
  ++stonesoup_global_variable;;
  scratchman_nondigestible(geomorphologic_uncompanionable);
}

void scratchman_nondigestible(struct angy_transversely edra_producible)
{
  ++stonesoup_global_variable;;
  predaciousness_taximan(edra_producible);
}

void predaciousness_taximan(struct angy_transversely unmatrimonially_baronetizing)
{
  ++stonesoup_global_variable;;
  pressure_reawakes(unmatrimonially_baronetizing);
}

void pressure_reawakes(struct angy_transversely pullicate_prurigo)
{
  ++stonesoup_global_variable;;
  schuyler_vascla(pullicate_prurigo);
}

void schuyler_vascla(struct angy_transversely offendedly_plunked)
{
  ++stonesoup_global_variable;;
  actinometricy_infuscate(offendedly_plunked);
}

void actinometricy_infuscate(struct angy_transversely subcauses_waste)
{
  ++stonesoup_global_variable;;
  mennonitism_nonrotation(subcauses_waste);
}

void mennonitism_nonrotation(struct angy_transversely pariah_unabrogated)
{
  ++stonesoup_global_variable;;
  sachiko_unneural(pariah_unabrogated);
}

void sachiko_unneural(struct angy_transversely kendo_unrespect)
{
  ++stonesoup_global_variable;;
  workfare_oxozone(kendo_unrespect);
}

void workfare_oxozone(struct angy_transversely coglorify_unthrones)
{
  ++stonesoup_global_variable;;
  undemocratized_trillionaire(coglorify_unthrones);
}

void undemocratized_trillionaire(struct angy_transversely prevenances_ottillia)
{
  ++stonesoup_global_variable;;
  glassfish_hairdodos(prevenances_ottillia);
}

void glassfish_hairdodos(struct angy_transversely zoaea_alit)
{
  ++stonesoup_global_variable;;
  formule_mycetological(zoaea_alit);
}

void formule_mycetological(struct angy_transversely untentered_papadopoulos)
{
  ++stonesoup_global_variable;;
  miquela_diarian(untentered_papadopoulos);
}

void miquela_diarian(struct angy_transversely kym_sorehead)
{
  ++stonesoup_global_variable;;
  enzymolytic_blameable(kym_sorehead);
}

void enzymolytic_blameable(struct angy_transversely quassias_duthie)
{
  ++stonesoup_global_variable;;
  phosphammonium_racketier(quassias_duthie);
}

void phosphammonium_racketier(struct angy_transversely ilmenitite_chariotman)
{
  ++stonesoup_global_variable;;
  lambs_drou(ilmenitite_chariotman);
}

void lambs_drou(struct angy_transversely spitzer_fluoric)
{
  ++stonesoup_global_variable;;
  codpitchings_thickskulled(spitzer_fluoric);
}

void codpitchings_thickskulled(struct angy_transversely sharefarmer_ashtrays)
{
  ++stonesoup_global_variable;;
  msornhort_yomin(sharefarmer_ashtrays);
}

void msornhort_yomin(struct angy_transversely fluoric_illumining)
{
  ++stonesoup_global_variable;;
  emirate_ciscos(fluoric_illumining);
}

void emirate_ciscos(struct angy_transversely ichthyolatry_cloddy)
{
  ++stonesoup_global_variable;;
  wronskian_subroutines(ichthyolatry_cloddy);
}

void wronskian_subroutines(struct angy_transversely sallets_firefanging)
{
  ++stonesoup_global_variable;;
  unfrilled_misworshiper(sallets_firefanging);
}

void unfrilled_misworshiper(struct angy_transversely macrodactylia_jeopardously)
{
  ++stonesoup_global_variable;;
  prezygomatic_gamba(macrodactylia_jeopardously);
}

void prezygomatic_gamba(struct angy_transversely quaily_austrium)
{
  ++stonesoup_global_variable;;
  megnetosphere_discolorment(quaily_austrium);
}

void megnetosphere_discolorment(struct angy_transversely phagocyte_muscled)
{
  ++stonesoup_global_variable;;
  creply_thuggeries(phagocyte_muscled);
}

void creply_thuggeries(struct angy_transversely caria_yetling)
{
  ++stonesoup_global_variable;;
  undiluted_initiatives(caria_yetling);
}

void undiluted_initiatives(struct angy_transversely bibliographize_neurergic)
{
  FILE *stonesoup_csv = 0;
  FILE *stonesoup_temp = 0;
  char stonesoup_col1[80] = {0};
  char stonesoup_col2[80] = {0};
  char stonesoup_col3[80] = {0};
  char *stonesoup_cols[3] = {0};
  char *herculeses_culttelli = 0;
  ++stonesoup_global_variable;;
  herculeses_culttelli = ((char *)bibliographize_neurergic . hypocrite_coram);
  tracepoint(stonesoup_trace, weakness_start, "CWE476", "A", "NULL Pointer Dereference");
  tracepoint(stonesoup_trace, variable_buffer, "STONESOUP_TAINT_SOURCE", herculeses_culttelli, "INITIAL-STATE");
  stonesoup_csv = fopen(herculeses_culttelli,"r");
  if (stonesoup_csv != 0) {
    tracepoint(stonesoup_trace, trace_point, "CROSSOVER-POINT: BEFORE");
/* STONESOUP: CROSSOVER-POINT (Syntactically Invalid Structure */
    fscanf(stonesoup_csv,"\"%79[^\"]\",\"%79[^\"]\",\"%79[^\"]\"",stonesoup_col1,stonesoup_col2,stonesoup_col3);
    tracepoint(stonesoup_trace, variable_buffer, "stonesoup_col1", stonesoup_col1, "CROSSOVER-STATE");
    tracepoint(stonesoup_trace, variable_buffer, "stonesoup_col2", stonesoup_col2, "CROSSOVER-STATE");
    tracepoint(stonesoup_trace, variable_buffer, "stonesoup_col3", stonesoup_col3, "CROSSOVER-STATE");
    tracepoint(stonesoup_trace, trace_point, "CROSSOVER-POINT: AFTER");
    if (strlen(stonesoup_col1) > 0)
        stonesoup_cols[0] = stonesoup_col1;
    if (strlen(stonesoup_col2) > 0)
        stonesoup_cols[1] = stonesoup_col2;
    if (strlen(stonesoup_col3) > 0)
        stonesoup_cols[2] = stonesoup_col3;
    stonesoup_temp = fopen("/opt/stonesoup/workspace/testData/myfile.txt", "w+");
    if(stonesoup_temp != 0) {
        tracepoint(stonesoup_trace, trace_point, "TRIGGER-POINT: BEFORE");
/* STONESOUP: TRIGGER-POINT (Syntactically Invalid Structure) */
        stonesoup_printf("VALUES=\"");
        fputs(stonesoup_cols[0],stonesoup_temp);
        stonesoup_printf(stonesoup_cols[0]);
        stonesoup_printf("\",\"");
        fputs(stonesoup_cols[1],stonesoup_temp);
        stonesoup_printf(stonesoup_cols[1]);
        stonesoup_printf("\",\"");
        fputs(stonesoup_cols[2],stonesoup_temp);
        stonesoup_printf(stonesoup_cols[2]);
        tracepoint(stonesoup_trace, trace_point, "TRIGGER-POINT: AFTER");
        stonesoup_printf("\"\n");
        fclose(stonesoup_temp);
    }
  }
  tracepoint(stonesoup_trace, weakness_end);
;
  if (bibliographize_neurergic . hypocrite_coram != 0) 
    free(((char *)bibliographize_neurergic . hypocrite_coram));
stonesoup_close_printf_context();
}
